summaryrefslogtreecommitdiff
path: root/gnu
diff options
context:
space:
mode:
authorEfraim Flashner <efraim@flashner.co.il>2021-08-22 14:03:53 +0300
committerEfraim Flashner <efraim@flashner.co.il>2021-08-22 14:08:54 +0300
commit06e258c3c08cdd78bf329e4c8a5543749f13d8d2 (patch)
treeb4a5fc860b472bda7fd8eb3f2f5c4a3c2b6e95f6 /gnu
parentc37bd286ea33f660086668d7b820e5c224ad6739 (diff)
gnu: python-jupyter-core: Use GUIX_PYTHONPATH.
* gnu/packages/python-xyz.scm (python-jupyter-core)[arguments]: Adjust custom 'patch-testsuite phase to use GUIX_PYTHONPATH as the PYTHONPATH.
Diffstat (limited to 'gnu')
-rw-r--r--gnu/packages/python-xyz.scm6
1 files changed, 3 insertions, 3 deletions
diff --git a/gnu/packages/python-xyz.scm b/gnu/packages/python-xyz.scm
index 6b4e622af8..f499a40ca4 100644
--- a/gnu/packages/python-xyz.scm
+++ b/gnu/packages/python-xyz.scm
@@ -7787,12 +7787,12 @@ without using the configuration machinery.")
(add-after 'unpack 'patch-testsuite
(lambda _
;; test_not_on_path() and test_path_priority() try to run a test
;; that loads jupyter_core, so we need PYTHONPATH
(substitute* "jupyter_core/tests/test_command.py"
(("env = \\{'PATH': ''\\}")
- "env = {'PATH': '', 'PYTHONPATH': os.environ['PYTHONPATH']}")
+ "env = {'PATH': '', 'PYTHONPATH': os.environ['GUIX_PYTHONPATH']}")
(("env = \\{'PATH': str\\(b\\)\\}")
- "env = {'PATH': str(b), 'PYTHONPATH': os.environ['PYTHONPATH']}"))
+ "env = {'PATH': str(b), 'PYTHONPATH': os.environ['GUIX_PYTHONPATH']}"))
#t))
;; Migration is running whenever etc/jupyter exists, but the
;; Guix-managed directory will never contain any migratable IPython
@@ -7787,12 +7787,12 @@ without using the configuration machinery.")
(lambda _
;; test_not_on_path() and test_path_priority() try to run a test
- ;; that loads jupyter_core, so we need PYTHONPATH
+ ;; that loads jupyter_core, so we need GUIX_PYTHONPATH
(substitute* "jupyter_core/tests/test_command.py"
(("env = \\{'PATH': ''\\}")